Package: SBOAtools
Type: Package
Title: Secretary Bird Optimization for Continuous Optimization and
        Neural Network Training
Version: 0.1.1
Authors@R: c(
    person("Burak", "Dilber", email = "burakdilber91@gmail.com", role = c("aut", "cre", "cph")),
    person("A. Fırat", "Özdemir", email = "firat.ozdemir5761@gmail.com", role = c("aut", "cph"))
    )
Description: Provides an implementation of Secretary Bird Optimization for
    general-purpose continuous optimization, benchmark optimization, and
    training single-hidden-layer feed-forward neural network models. The
    implemented optimizer is based on the Secretary Bird Optimization Algorithm
    proposed by Fu et al. (2024) <doi:10.1007/s10462-024-10729-y>. The neural
    network training functionality is based on Dilber and Özdemir (2026)
    <doi:10.1007/s00521-026-11874-x>.
License: MIT + file LICENSE
URL: https://github.com/burakdilber/SBOAtools
BugReports: https://github.com/burakdilber/SBOAtools/issues
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: stats, graphics
NeedsCompilation: no
Packaged: 2026-05-02 15:20:24 UTC; hp
Author: Burak Dilber [aut, cre, cph],
  A. Fırat Özdemir [aut, cph]
Maintainer: Burak Dilber <burakdilber91@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-03 06:30:17 UTC
Built: R 4.5.2; ; 2026-05-03 08:28:14 UTC; unix
