# Generated by roxygen2: do not edit by hand

S3method(plot,sboa)
S3method(plot,sboa_mlp)
S3method(predict,sboa_mlp)
S3method(print,sboa)
S3method(print,sboa_mlp)
export(get_benchmark)
export(list_benchmarks)
export(sboa)
export(sboa_mlp)
importFrom(stats,rnorm)
importFrom(stats,runif)
