% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sboa_mlp.R
\name{plot.sboa_mlp}
\alias{plot.sboa_mlp}
\title{Plot method for SBOA-MLP objects}
\usage{
\method{plot}{sboa_mlp}(x, ...)
}
\arguments{
\item{x}{An object of class \code{"sboa_mlp"}.}

\item{...}{Additional graphical arguments passed to \code{graphics::plot()}.}
}
\value{
No return value. Called for its side effect.
}
\description{
Plots the convergence curve of a trained SBOA-MLP model.
}
