% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{clip_bounds}
\alias{clip_bounds}
\title{Clip values to lower and upper bounds}
\usage{
clip_bounds(x, lower, upper)
}
\arguments{
\item{x}{Numeric vector.}

\item{lower}{Lower bound vector.}

\item{upper}{Upper bound vector.}
}
\value{
A bounded numeric vector.
}
\description{
Restricts each element of a vector to the given bounds.
}
