% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{levy_flight}
\alias{levy_flight}
\title{Lévy flight step generator}
\usage{
levy_flight(d, beta = 1.5)
}
\arguments{
\item{d}{Dimension of the step vector.}

\item{beta}{Stability parameter.}
}
\value{
A numeric vector of length \code{d}.
}
\description{
Generates Lévy-distributed random steps.
}
