% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sboa_mlp.R
\name{print.sboa_mlp}
\alias{print.sboa_mlp}
\title{Print method for SBOA-MLP objects}
\usage{
\method{print}{sboa_mlp}(x, ...)
}
\arguments{
\item{x}{An object of class \code{"sboa_mlp"}.}

\item{...}{Additional arguments, ignored.}
}
\value{
The input object, invisibly.
}
\description{
Prints a summary of a trained SBOA-MLP model.
}
