% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{sigmoid}
\alias{sigmoid}
\title{Sigmoid activation function}
\usage{
sigmoid(x)
}
\arguments{
\item{x}{A numeric vector, matrix, or scalar.}
}
\value{
Transformed values in the interval (0, 1).
}
\description{
Computes the sigmoid transformation.
}
