% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{apply_minmax}
\alias{apply_minmax}
\title{Apply min-max normalization using existing bounds}
\usage{
apply_minmax(x, mins, maxs)
}
\arguments{
\item{x}{Numeric vector or matrix.}

\item{mins}{Column minima.}

\item{maxs}{Column maxima.}
}
\value{
Scaled matrix.
}
\description{
Apply min-max normalization using existing bounds
}
