% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sboa_mlp.R
\name{predict.sboa_mlp}
\alias{predict.sboa_mlp}
\title{Predict method for SBOA-MLP objects}
\usage{
\method{predict}{sboa_mlp}(object, newdata, ...)
}
\arguments{
\item{object}{An object of class \code{"sboa_mlp"}.}

\item{newdata}{New predictor data.}

\item{...}{Additional arguments, ignored.}
}
\value{
A matrix of predicted values.
}
\description{
Generates predictions from a trained SBOA-MLP model.
}
