% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{normalize_minmax}
\alias{normalize_minmax}
\title{Min-max normalization}
\usage{
normalize_minmax(x)
}
\arguments{
\item{x}{Numeric vector or matrix.}
}
\value{
A list containing scaled data and min-max values.
}
\description{
Scales each column of a matrix to the interval from 0 to 1.
}
