% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/metrics.R
\name{mae_vec}
\alias{mae_vec}
\title{Mean absolute error}
\usage{
mae_vec(actual, predicted)
}
\arguments{
\item{actual}{Numeric vector or matrix of observed values.}

\item{predicted}{Numeric vector or matrix of predicted values.}
}
\value{
A numeric scalar.
}
\description{
Computes the mean absolute error between actual and predicted values.
}
