% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sboa_methods.R
\name{plot.sboa}
\alias{plot.sboa}
\title{Plot method for SBOA objects}
\usage{
\method{plot}{sboa}(x, ...)
}
\arguments{
\item{x}{An object of class \code{"sboa"}.}

\item{...}{Additional graphical arguments passed to \code{plot()}.}
}
\value{
No return value. Called for its side effect.
}
\description{
Plots the convergence curve of an SBOA optimization result.
}
