% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/benchmarks.R
\name{list_benchmarks}
\alias{list_benchmarks}
\title{List built-in benchmark functions}
\usage{
list_benchmarks()
}
\value{
A data frame.
}
\description{
Returns a summary table of the built-in F1-F23 benchmark functions.
}
\examples{
list_benchmarks()
}
