% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{denormalize_minmax}
\alias{denormalize_minmax}
\title{Reverse min-max normalization}
\usage{
denormalize_minmax(x_scaled, mins, maxs)
}
\arguments{
\item{x_scaled}{Scaled numeric vector or matrix.}

\item{mins}{Column minima.}

\item{maxs}{Column maxima.}
}
\value{
Values on the original scale.
}
\description{
Reverse min-max normalization
}
